.. _statistics:

Translation statistics
======================

Pootle gives translators and project developers an easy way to see progress on
the translation work.  Progress is indicated by a coloured graph to easily see
how much work is complete, and how much work remains. Pootle can also give
detailed statistics about the progress in translation work.

Statistics report on both the progress in the number of messages, and in the
number of words.  The number of words gives a much better impression of how
much work is involved, and allows for more accurate time estimation.

Pootle also assists in translation quality assurance, by performing several
:doc:`checks` on the translations which can help in review. These quality
checks correspond to the :ref:`quality checks <toolkit:pofilter_tests>`
performed by :ref:`pofilter <toolkit:pofilter>` from the Translate Toolkit.
